@@ -2,8 +2,8 @@ import discord
 from discord.ext import commands
 import time
 import os
-
 from colorama import init, Fore, Style
+
 init()
 
 def yellow(text):
@@ -15,7 +15,6 @@ def green(text):
 def red(text):
 	return Fore.RED + text + Style.RESET_ALL
 
-
 class bot:
 	def __init__(self, settings: {settings['logging']: "advanced"}):
 		self.bot = '';
@@ -70,4 +69,7 @@ class bot:
 			return {'logging': self.logging, "prefix": self.prefix}
 
 		def getAll(self):
-			return {'settings': {'logging': self.logging, "prefix": self.prefix}, "bot": self.bot}
\ No newline at end of file
+			return {'settings': {'logging': self.logging, "prefix": self.prefix}, "bot": self.bot}
+
+def getBot():
+	return bot
\ No newline at end of file
